# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/ad_type_infos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import ad_asset_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2
from google.ads.google_ads.v2.proto.enums import call_conversion_reporting_state_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2
from google.ads.google_ads.v2.proto.enums import display_ad_format_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__ad__format__setting__pb2
from google.ads.google_ads.v2.proto.enums import display_upload_product_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__upload__product__type__pb2
from google.ads.google_ads.v2.proto.enums import legacy_app_install_ad_app_store_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_legacy__app__install__ad__app__store__pb2
from google.ads.google_ads.v2.proto.enums import mime_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/ad_type_infos.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\020AdTypeInfosProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n8google/ads/googleads_v2/proto/common/ad_type_infos.proto\x12\x1egoogle.ads.googleads.v2.common\x1a\x33google/ads/googleads_v2/proto/common/ad_asset.proto\x1aIgoogle/ads/googleads_v2/proto/enums/call_conversion_reporting_state.proto\x1a\x43google/ads/googleads_v2/proto/enums/display_ad_format_setting.proto\x1a\x45google/ads/googleads_v2/proto/enums/display_upload_product_type.proto\x1aIgoogle/ads/googleads_v2/proto/enums/legacy_app_install_ad_app_store.proto\x1a\x33google/ads/googleads_v2/proto/enums/mime_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x01\n\nTextAdInfo\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription1\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf7\x02\n\x12\x45xpandedTextAdInfo\x12\x34\n\x0eheadline_part1\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eheadline_part2\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eheadline_part3\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05path1\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05path2\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xe7\x05\n\x0e\x43\x61llOnlyAdInfo\x12\x32\n\x0c\x63ountry_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cphone_number\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\theadline1\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\theadline2\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription1\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0c\x63\x61ll_tracked\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x17\x64isable_call_conversion\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1dphone_number_verification_url\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x80\x01\n\x1a\x63onversion_reporting_state\x18\n \x01(\x0e\x32\\.google.ads.googleads.v2.enums.CallConversionReportingStateEnum.CallConversionReportingState\"\x84\x01\n\x1b\x45xpandedDynamicSearchAdInfo\x12\x31\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\r\n\x0bHotelAdInfo\"\x15\n\x13ShoppingSmartAdInfo\"\x17\n\x15ShoppingProductAdInfo\"Q\n\x1fShoppingComparisonListingAdInfo\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x04\n\x0bGmailAdInfo\x12;\n\x06teaser\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v2.common.GmailTeaser\x12\x32\n\x0cheader_image\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fmarketing_image\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18marketing_image_headline\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x41\n\x1bmarketing_image_description\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x63\n&marketing_image_display_call_to_action\x18\x06 \x01(\x0b\x32\x33.google.ads.googleads.v2.common.DisplayCallToAction\x12\x44\n\x0eproduct_images\x18\x07 \x03(\x0b\x32,.google.ads.googleads.v2.common.ProductImage\x12\x44\n\x0eproduct_videos\x18\x08 \x03(\x0b\x32,.google.ads.googleads.v2.common.ProductVideo\"\xd7\x01\n\x0bGmailTeaser\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nlogo_image\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xac\x01\n\x13\x44isplayCallToAction\x12*\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ntext_color\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11url_collection_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xcb\x01\n\x0cProductImage\x12\x33\n\rproduct_image\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12S\n\x16\x64isplay_call_to_action\x18\x03 \x01(\x0b\x32\x33.google.ads.googleads.v2.common.DisplayCallToAction\"C\n\x0cProductVideo\x12\x33\n\rproduct_video\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf1\x04\n\x0bImageAdInfo\x12\x30\n\x0bpixel_width\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cpixel_height\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\timage_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x13preview_pixel_width\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14preview_pixel_height\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x11preview_image_url\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n\tmime_type\x18\n \x01(\x0e\x32\x34.google.ads.googleads.v2.enums.MimeTypeEnum.MimeType\x12*\n\x04name\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\nmedia_file\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x12?\n\x18\x61\x64_id_to_copy_image_from\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00\x42\x07\n\x05image\"S\n\x19VideoBumperInStreamAdInfo\x12\x36\n\x10\x63ompanion_banner\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"Y\n\x1fVideoNonSkippableInStreamAdInfo\x12\x36\n\x10\x63ompanion_banner\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xc7\x01\n\x1bVideoTrueViewInStreamAdInfo\x12\x39\n\x13\x61\x63tion_button_label\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x61\x63tion_headline\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x63ompanion_banner\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"y\n\x14VideoOutstreamAdInfo\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x8e\x03\n\x0bVideoAdInfo\x12\x30\n\nmedia_file\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12P\n\tin_stream\x18\x02 \x01(\x0b\x32;.google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfoH\x00\x12K\n\x06\x62umper\x18\x03 \x01(\x0b\x32\x39.google.ads.googleads.v2.common.VideoBumperInStreamAdInfoH\x00\x12J\n\nout_stream\x18\x04 \x01(\x0b\x32\x34.google.ads.googleads.v2.common.VideoOutstreamAdInfoH\x00\x12X\n\rnon_skippable\x18\x05 \x01(\x0b\x32?.google.ads.googleads.v2.common.VideoNonSkippableInStreamAdInfoH\x00\x42\x08\n\x06\x66ormat\"\xf5\x01\n\x16ResponsiveSearchAdInfo\x12>\n\theadlines\x18\x01 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x41\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12+\n\x05path1\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05path2\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xfd\x06\n\x1dLegacyResponsiveDisplayAdInfo\x12\x34\n\x0eshort_headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlong_headline\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x14\x61llow_flexible_color\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0c\x61\x63\x63\x65nt_color\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nmain_color\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x63\x61ll_to_action_text\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nlogo_image\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11square_logo_image\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fmarketing_image\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x16square_marketing_image\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12h\n\x0e\x66ormat_setting\x18\r \x01(\x0e\x32P.google.ads.googleads.v2.enums.DisplayAdFormatSettingEnum.DisplayAdFormatSetting\x12\x32\n\x0cprice_prefix\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\npromo_text\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xab\x03\n\tAppAdInfo\x12\x46\n\x11mandatory_ad_text\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12>\n\theadlines\x18\x02 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x41\n\x0c\x64\x65scriptions\x18\x03 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12<\n\x06images\x18\x04 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12\x44\n\x0eyoutube_videos\x18\x05 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdVideoAsset\x12O\n\x13html5_media_bundles\x18\x06 \x03(\x0b\x32\x32.google.ads.googleads.v2.common.AdMediaBundleAsset\"\x94\x02\n\x13\x41ppEngagementAdInfo\x12>\n\theadlines\x18\x01 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x41\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12<\n\x06images\x18\x03 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12<\n\x06videos\x18\x04 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdVideoAsset\"\xcb\x02\n\x16LegacyAppInstallAdInfo\x12,\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12k\n\tapp_store\x18\x02 \x01(\x0e\x32X.google.ads.googleads.v2.enums.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore\x12.\n\x08headline\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription1\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xaa\x08\n\x17ResponsiveDisplayAdInfo\x12\x46\n\x10marketing_images\x18\x01 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12M\n\x17square_marketing_images\x18\x02 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12\x41\n\x0blogo_images\x18\x03 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12H\n\x12square_logo_images\x18\x04 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdImageAsset\x12>\n\theadlines\x18\x05 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x42\n\rlong_headline\x18\x06 \x01(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x41\n\x0c\x64\x65scriptions\x18\x07 \x03(\x0b\x32+.google.ads.googleads.v2.common.AdTextAsset\x12\x44\n\x0eyoutube_videos\x18\x08 \x03(\x0b\x32,.google.ads.googleads.v2.common.AdVideoAsset\x12\x33\n\rbusiness_name\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nmain_color\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x61\x63\x63\x65nt_color\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x14\x61llow_flexible_color\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x13\x63\x61ll_to_action_text\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cprice_prefix\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\npromo_text\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12h\n\x0e\x66ormat_setting\x18\x10 \x01(\x0e\x32P.google.ads.googleads.v2.enums.DisplayAdFormatSettingEnum.DisplayAdFormatSetting\"\xeb\x01\n\x13\x44isplayUploadAdInfo\x12y\n\x1b\x64isplay_upload_product_type\x18\x01 \x01(\x0e\x32T.google.ads.googleads.v2.enums.DisplayUploadProductTypeEnum.DisplayUploadProductType\x12J\n\x0cmedia_bundle\x18\x02 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.AdMediaBundleAssetH\x00\x42\r\n\x0bmedia_assetB\xeb\x01\n\"com.google.ads.googleads.v2.commonB\x10\x41\x64TypeInfosProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__ad__format__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__upload__product__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_legacy__app__install__ad__app__store__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_TEXTADINFO = _descriptor.Descriptor(
  name='TextAdInfo',
  full_name='google.ads.googleads.v2.common.TextAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.common.TextAdInfo.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v2.common.TextAdInfo.description1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v2.common.TextAdInfo.description2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=715,
)


_EXPANDEDTEXTADINFO = _descriptor.Descriptor(
  name='ExpandedTextAdInfo',
  full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline_part1', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.headline_part1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline_part2', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.headline_part2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline_part3', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.headline_part3', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.description', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.description2', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path1', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.path1', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path2', full_name='google.ads.googleads.v2.common.ExpandedTextAdInfo.path2', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=1093,
)


_CALLONLYADINFO = _descriptor.Descriptor(
  name='CallOnlyAdInfo',
  full_name='google.ads.googleads.v2.common.CallOnlyAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.country_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.phone_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.business_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline1', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.headline1', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline2', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.headline2', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.description1', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.description2', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_tracked', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.call_tracked', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_call_conversion', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.disable_call_conversion', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number_verification_url', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.phone_number_verification_url', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.conversion_action', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_reporting_state', full_name='google.ads.googleads.v2.common.CallOnlyAdInfo.conversion_reporting_state', index=11,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1839,
)


_EXPANDEDDYNAMICSEARCHADINFO = _descriptor.Descriptor(
  name='ExpandedDynamicSearchAdInfo',
  full_name='google.ads.googleads.v2.common.ExpandedDynamicSearchAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.ExpandedDynamicSearchAdInfo.description', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v2.common.ExpandedDynamicSearchAdInfo.description2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1974,
)


_HOTELADINFO = _descriptor.Descriptor(
  name='HotelAdInfo',
  full_name='google.ads.googleads.v2.common.HotelAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=1989,
)


_SHOPPINGSMARTADINFO = _descriptor.Descriptor(
  name='ShoppingSmartAdInfo',
  full_name='google.ads.googleads.v2.common.ShoppingSmartAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1991,
  serialized_end=2012,
)


_SHOPPINGPRODUCTADINFO = _descriptor.Descriptor(
  name='ShoppingProductAdInfo',
  full_name='google.ads.googleads.v2.common.ShoppingProductAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2014,
  serialized_end=2037,
)


_SHOPPINGCOMPARISONLISTINGADINFO = _descriptor.Descriptor(
  name='ShoppingComparisonListingAdInfo',
  full_name='google.ads.googleads.v2.common.ShoppingComparisonListingAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.common.ShoppingComparisonListingAdInfo.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2120,
)


_GMAILADINFO = _descriptor.Descriptor(
  name='GmailAdInfo',
  full_name='google.ads.googleads.v2.common.GmailAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teaser', full_name='google.ads.googleads.v2.common.GmailAdInfo.teaser', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_image', full_name='google.ads.googleads.v2.common.GmailAdInfo.header_image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image', full_name='google.ads.googleads.v2.common.GmailAdInfo.marketing_image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_headline', full_name='google.ads.googleads.v2.common.GmailAdInfo.marketing_image_headline', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_description', full_name='google.ads.googleads.v2.common.GmailAdInfo.marketing_image_description', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_display_call_to_action', full_name='google.ads.googleads.v2.common.GmailAdInfo.marketing_image_display_call_to_action', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_images', full_name='google.ads.googleads.v2.common.GmailAdInfo.product_images', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_videos', full_name='google.ads.googleads.v2.common.GmailAdInfo.product_videos', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2676,
)


_GMAILTEASER = _descriptor.Descriptor(
  name='GmailTeaser',
  full_name='google.ads.googleads.v2.common.GmailTeaser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.common.GmailTeaser.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.GmailTeaser.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.GmailTeaser.business_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_image', full_name='google.ads.googleads.v2.common.GmailTeaser.logo_image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2679,
  serialized_end=2894,
)


_DISPLAYCALLTOACTION = _descriptor.Descriptor(
  name='DisplayCallToAction',
  full_name='google.ads.googleads.v2.common.DisplayCallToAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v2.common.DisplayCallToAction.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_color', full_name='google.ads.googleads.v2.common.DisplayCallToAction.text_color', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_collection_id', full_name='google.ads.googleads.v2.common.DisplayCallToAction.url_collection_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2897,
  serialized_end=3069,
)


_PRODUCTIMAGE = _descriptor.Descriptor(
  name='ProductImage',
  full_name='google.ads.googleads.v2.common.ProductImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_image', full_name='google.ads.googleads.v2.common.ProductImage.product_image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.ProductImage.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_call_to_action', full_name='google.ads.googleads.v2.common.ProductImage.display_call_to_action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3072,
  serialized_end=3275,
)


_PRODUCTVIDEO = _descriptor.Descriptor(
  name='ProductVideo',
  full_name='google.ads.googleads.v2.common.ProductVideo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_video', full_name='google.ads.googleads.v2.common.ProductVideo.product_video', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3277,
  serialized_end=3344,
)


_IMAGEADINFO = _descriptor.Descriptor(
  name='ImageAdInfo',
  full_name='google.ads.googleads.v2.common.ImageAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pixel_width', full_name='google.ads.googleads.v2.common.ImageAdInfo.pixel_width', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_height', full_name='google.ads.googleads.v2.common.ImageAdInfo.pixel_height', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='google.ads.googleads.v2.common.ImageAdInfo.image_url', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_pixel_width', full_name='google.ads.googleads.v2.common.ImageAdInfo.preview_pixel_width', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_pixel_height', full_name='google.ads.googleads.v2.common.ImageAdInfo.preview_pixel_height', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_image_url', full_name='google.ads.googleads.v2.common.ImageAdInfo.preview_image_url', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='google.ads.googleads.v2.common.ImageAdInfo.mime_type', index=6,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.common.ImageAdInfo.name', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file', full_name='google.ads.googleads.v2.common.ImageAdInfo.media_file', index=8,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v2.common.ImageAdInfo.data', index=9,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_id_to_copy_image_from', full_name='google.ads.googleads.v2.common.ImageAdInfo.ad_id_to_copy_image_from', index=10,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='image', full_name='google.ads.googleads.v2.common.ImageAdInfo.image',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3347,
  serialized_end=3972,
)


_VIDEOBUMPERINSTREAMADINFO = _descriptor.Descriptor(
  name='VideoBumperInStreamAdInfo',
  full_name='google.ads.googleads.v2.common.VideoBumperInStreamAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='companion_banner', full_name='google.ads.googleads.v2.common.VideoBumperInStreamAdInfo.companion_banner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3974,
  serialized_end=4057,
)


_VIDEONONSKIPPABLEINSTREAMADINFO = _descriptor.Descriptor(
  name='VideoNonSkippableInStreamAdInfo',
  full_name='google.ads.googleads.v2.common.VideoNonSkippableInStreamAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='companion_banner', full_name='google.ads.googleads.v2.common.VideoNonSkippableInStreamAdInfo.companion_banner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4059,
  serialized_end=4148,
)


_VIDEOTRUEVIEWINSTREAMADINFO = _descriptor.Descriptor(
  name='VideoTrueViewInStreamAdInfo',
  full_name='google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_button_label', full_name='google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfo.action_button_label', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_headline', full_name='google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfo.action_headline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='companion_banner', full_name='google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfo.companion_banner', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4151,
  serialized_end=4350,
)


_VIDEOOUTSTREAMADINFO = _descriptor.Descriptor(
  name='VideoOutstreamAdInfo',
  full_name='google.ads.googleads.v2.common.VideoOutstreamAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.common.VideoOutstreamAdInfo.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.VideoOutstreamAdInfo.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4352,
  serialized_end=4473,
)


_VIDEOADINFO = _descriptor.Descriptor(
  name='VideoAdInfo',
  full_name='google.ads.googleads.v2.common.VideoAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='media_file', full_name='google.ads.googleads.v2.common.VideoAdInfo.media_file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_stream', full_name='google.ads.googleads.v2.common.VideoAdInfo.in_stream', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bumper', full_name='google.ads.googleads.v2.common.VideoAdInfo.bumper', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_stream', full_name='google.ads.googleads.v2.common.VideoAdInfo.out_stream', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_skippable', full_name='google.ads.googleads.v2.common.VideoAdInfo.non_skippable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='format', full_name='google.ads.googleads.v2.common.VideoAdInfo.format',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4476,
  serialized_end=4874,
)


_RESPONSIVESEARCHADINFO = _descriptor.Descriptor(
  name='ResponsiveSearchAdInfo',
  full_name='google.ads.googleads.v2.common.ResponsiveSearchAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headlines', full_name='google.ads.googleads.v2.common.ResponsiveSearchAdInfo.headlines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='google.ads.googleads.v2.common.ResponsiveSearchAdInfo.descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path1', full_name='google.ads.googleads.v2.common.ResponsiveSearchAdInfo.path1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path2', full_name='google.ads.googleads.v2.common.ResponsiveSearchAdInfo.path2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4877,
  serialized_end=5122,
)


_LEGACYRESPONSIVEDISPLAYADINFO = _descriptor.Descriptor(
  name='LegacyResponsiveDisplayAdInfo',
  full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='short_headline', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.short_headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_headline', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.long_headline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.business_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_flexible_color', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.allow_flexible_color', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accent_color', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.accent_color', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_color', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.main_color', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_to_action_text', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.call_to_action_text', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_image', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.logo_image', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_logo_image', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.square_logo_image', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.marketing_image', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_marketing_image', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.square_marketing_image', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_setting', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.format_setting', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_prefix', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.price_prefix', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promo_text', full_name='google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo.promo_text', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5125,
  serialized_end=6018,
)


_APPADINFO = _descriptor.Descriptor(
  name='AppAdInfo',
  full_name='google.ads.googleads.v2.common.AppAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mandatory_ad_text', full_name='google.ads.googleads.v2.common.AppAdInfo.mandatory_ad_text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headlines', full_name='google.ads.googleads.v2.common.AppAdInfo.headlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='google.ads.googleads.v2.common.AppAdInfo.descriptions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='images', full_name='google.ads.googleads.v2.common.AppAdInfo.images', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_videos', full_name='google.ads.googleads.v2.common.AppAdInfo.youtube_videos', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='html5_media_bundles', full_name='google.ads.googleads.v2.common.AppAdInfo.html5_media_bundles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6021,
  serialized_end=6448,
)


_APPENGAGEMENTADINFO = _descriptor.Descriptor(
  name='AppEngagementAdInfo',
  full_name='google.ads.googleads.v2.common.AppEngagementAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headlines', full_name='google.ads.googleads.v2.common.AppEngagementAdInfo.headlines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='google.ads.googleads.v2.common.AppEngagementAdInfo.descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='images', full_name='google.ads.googleads.v2.common.AppEngagementAdInfo.images', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='videos', full_name='google.ads.googleads.v2.common.AppEngagementAdInfo.videos', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6451,
  serialized_end=6727,
)


_LEGACYAPPINSTALLADINFO = _descriptor.Descriptor(
  name='LegacyAppInstallAdInfo',
  full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_store', full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo.app_store', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo.headline', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo.description1', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v2.common.LegacyAppInstallAdInfo.description2', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6730,
  serialized_end=7061,
)


_RESPONSIVEDISPLAYADINFO = _descriptor.Descriptor(
  name='ResponsiveDisplayAdInfo',
  full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketing_images', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.marketing_images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_marketing_images', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.square_marketing_images', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_images', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.logo_images', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_logo_images', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.square_logo_images', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headlines', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.headlines', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_headline', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.long_headline', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.descriptions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_videos', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.youtube_videos', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.business_name', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_color', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.main_color', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accent_color', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.accent_color', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_flexible_color', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.allow_flexible_color', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_to_action_text', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.call_to_action_text', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_prefix', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.price_prefix', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promo_text', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.promo_text', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_setting', full_name='google.ads.googleads.v2.common.ResponsiveDisplayAdInfo.format_setting', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7064,
  serialized_end=8130,
)


_DISPLAYUPLOADADINFO = _descriptor.Descriptor(
  name='DisplayUploadAdInfo',
  full_name='google.ads.googleads.v2.common.DisplayUploadAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='display_upload_product_type', full_name='google.ads.googleads.v2.common.DisplayUploadAdInfo.display_upload_product_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_bundle', full_name='google.ads.googleads.v2.common.DisplayUploadAdInfo.media_bundle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='media_asset', full_name='google.ads.googleads.v2.common.DisplayUploadAdInfo.media_asset',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=8133,
  serialized_end=8368,
)

_TEXTADINFO.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['path1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['path2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['headline1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['headline2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['call_tracked'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLONLYADINFO.fields_by_name['disable_call_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLONLYADINFO.fields_by_name['phone_number_verification_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['conversion_reporting_state'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2._CALLCONVERSIONREPORTINGSTATEENUM_CALLCONVERSIONREPORTINGSTATE
_EXPANDEDDYNAMICSEARCHADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDDYNAMICSEARCHADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SHOPPINGCOMPARISONLISTINGADINFO.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['teaser'].message_type = _GMAILTEASER
_GMAILADINFO.fields_by_name['header_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_display_call_to_action'].message_type = _DISPLAYCALLTOACTION
_GMAILADINFO.fields_by_name['product_images'].message_type = _PRODUCTIMAGE
_GMAILADINFO.fields_by_name['product_videos'].message_type = _PRODUCTVIDEO
_GMAILTEASER.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISPLAYCALLTOACTION.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISPLAYCALLTOACTION.fields_by_name['text_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISPLAYCALLTOACTION.fields_by_name['url_collection_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTIMAGE.fields_by_name['product_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTIMAGE.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTIMAGE.fields_by_name['display_call_to_action'].message_type = _DISPLAYCALLTOACTION
_PRODUCTVIDEO.fields_by_name['product_video'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['pixel_width'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['pixel_height'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['image_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['preview_pixel_width'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['preview_pixel_height'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['preview_image_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['mime_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2._MIMETYPEENUM_MIMETYPE
_IMAGEADINFO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['media_file'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_IMAGEADINFO.fields_by_name['ad_id_to_copy_image_from'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.oneofs_by_name['image'].fields.append(
  _IMAGEADINFO.fields_by_name['media_file'])
_IMAGEADINFO.fields_by_name['media_file'].containing_oneof = _IMAGEADINFO.oneofs_by_name['image']
_IMAGEADINFO.oneofs_by_name['image'].fields.append(
  _IMAGEADINFO.fields_by_name['data'])
_IMAGEADINFO.fields_by_name['data'].containing_oneof = _IMAGEADINFO.oneofs_by_name['image']
_IMAGEADINFO.oneofs_by_name['image'].fields.append(
  _IMAGEADINFO.fields_by_name['ad_id_to_copy_image_from'])
_IMAGEADINFO.fields_by_name['ad_id_to_copy_image_from'].containing_oneof = _IMAGEADINFO.oneofs_by_name['image']
_VIDEOBUMPERINSTREAMADINFO.fields_by_name['companion_banner'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEONONSKIPPABLEINSTREAMADINFO.fields_by_name['companion_banner'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOTRUEVIEWINSTREAMADINFO.fields_by_name['action_button_label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOTRUEVIEWINSTREAMADINFO.fields_by_name['action_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOTRUEVIEWINSTREAMADINFO.fields_by_name['companion_banner'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOOUTSTREAMADINFO.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOOUTSTREAMADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOADINFO.fields_by_name['media_file'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VIDEOADINFO.fields_by_name['in_stream'].message_type = _VIDEOTRUEVIEWINSTREAMADINFO
_VIDEOADINFO.fields_by_name['bumper'].message_type = _VIDEOBUMPERINSTREAMADINFO
_VIDEOADINFO.fields_by_name['out_stream'].message_type = _VIDEOOUTSTREAMADINFO
_VIDEOADINFO.fields_by_name['non_skippable'].message_type = _VIDEONONSKIPPABLEINSTREAMADINFO
_VIDEOADINFO.oneofs_by_name['format'].fields.append(
  _VIDEOADINFO.fields_by_name['in_stream'])
_VIDEOADINFO.fields_by_name['in_stream'].containing_oneof = _VIDEOADINFO.oneofs_by_name['format']
_VIDEOADINFO.oneofs_by_name['format'].fields.append(
  _VIDEOADINFO.fields_by_name['bumper'])
_VIDEOADINFO.fields_by_name['bumper'].containing_oneof = _VIDEOADINFO.oneofs_by_name['format']
_VIDEOADINFO.oneofs_by_name['format'].fields.append(
  _VIDEOADINFO.fields_by_name['out_stream'])
_VIDEOADINFO.fields_by_name['out_stream'].containing_oneof = _VIDEOADINFO.oneofs_by_name['format']
_VIDEOADINFO.oneofs_by_name['format'].fields.append(
  _VIDEOADINFO.fields_by_name['non_skippable'])
_VIDEOADINFO.fields_by_name['non_skippable'].containing_oneof = _VIDEOADINFO.oneofs_by_name['format']
_RESPONSIVESEARCHADINFO.fields_by_name['headlines'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_RESPONSIVESEARCHADINFO.fields_by_name['descriptions'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_RESPONSIVESEARCHADINFO.fields_by_name['path1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVESEARCHADINFO.fields_by_name['path2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['short_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['long_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['allow_flexible_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['accent_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['main_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['call_to_action_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['square_logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['square_marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['format_setting'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__ad__format__setting__pb2._DISPLAYADFORMATSETTINGENUM_DISPLAYADFORMATSETTING
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['price_prefix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYRESPONSIVEDISPLAYADINFO.fields_by_name['promo_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPADINFO.fields_by_name['mandatory_ad_text'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_APPADINFO.fields_by_name['headlines'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_APPADINFO.fields_by_name['descriptions'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_APPADINFO.fields_by_name['images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_APPADINFO.fields_by_name['youtube_videos'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADVIDEOASSET
_APPADINFO.fields_by_name['html5_media_bundles'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADMEDIABUNDLEASSET
_APPENGAGEMENTADINFO.fields_by_name['headlines'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_APPENGAGEMENTADINFO.fields_by_name['descriptions'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_APPENGAGEMENTADINFO.fields_by_name['images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_APPENGAGEMENTADINFO.fields_by_name['videos'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADVIDEOASSET
_LEGACYAPPINSTALLADINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYAPPINSTALLADINFO.fields_by_name['app_store'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_legacy__app__install__ad__app__store__pb2._LEGACYAPPINSTALLADAPPSTOREENUM_LEGACYAPPINSTALLADAPPSTORE
_LEGACYAPPINSTALLADINFO.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYAPPINSTALLADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LEGACYAPPINSTALLADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['marketing_images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['square_marketing_images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['logo_images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['square_logo_images'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADIMAGEASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['headlines'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['long_headline'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['descriptions'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADTEXTASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['youtube_videos'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADVIDEOASSET
_RESPONSIVEDISPLAYADINFO.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['main_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['accent_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['allow_flexible_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['call_to_action_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['price_prefix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['promo_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['format_setting'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__ad__format__setting__pb2._DISPLAYADFORMATSETTINGENUM_DISPLAYADFORMATSETTING
_DISPLAYUPLOADADINFO.fields_by_name['display_upload_product_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_display__upload__product__type__pb2._DISPLAYUPLOADPRODUCTTYPEENUM_DISPLAYUPLOADPRODUCTTYPE
_DISPLAYUPLOADADINFO.fields_by_name['media_bundle'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_ad__asset__pb2._ADMEDIABUNDLEASSET
_DISPLAYUPLOADADINFO.oneofs_by_name['media_asset'].fields.append(
  _DISPLAYUPLOADADINFO.fields_by_name['media_bundle'])
_DISPLAYUPLOADADINFO.fields_by_name['media_bundle'].containing_oneof = _DISPLAYUPLOADADINFO.oneofs_by_name['media_asset']
DESCRIPTOR.message_types_by_name['TextAdInfo'] = _TEXTADINFO
DESCRIPTOR.message_types_by_name['ExpandedTextAdInfo'] = _EXPANDEDTEXTADINFO
DESCRIPTOR.message_types_by_name['CallOnlyAdInfo'] = _CALLONLYADINFO
DESCRIPTOR.message_types_by_name['ExpandedDynamicSearchAdInfo'] = _EXPANDEDDYNAMICSEARCHADINFO
DESCRIPTOR.message_types_by_name['HotelAdInfo'] = _HOTELADINFO
DESCRIPTOR.message_types_by_name['ShoppingSmartAdInfo'] = _SHOPPINGSMARTADINFO
DESCRIPTOR.message_types_by_name['ShoppingProductAdInfo'] = _SHOPPINGPRODUCTADINFO
DESCRIPTOR.message_types_by_name['ShoppingComparisonListingAdInfo'] = _SHOPPINGCOMPARISONLISTINGADINFO
DESCRIPTOR.message_types_by_name['GmailAdInfo'] = _GMAILADINFO
DESCRIPTOR.message_types_by_name['GmailTeaser'] = _GMAILTEASER
DESCRIPTOR.message_types_by_name['DisplayCallToAction'] = _DISPLAYCALLTOACTION
DESCRIPTOR.message_types_by_name['ProductImage'] = _PRODUCTIMAGE
DESCRIPTOR.message_types_by_name['ProductVideo'] = _PRODUCTVIDEO
DESCRIPTOR.message_types_by_name['ImageAdInfo'] = _IMAGEADINFO
DESCRIPTOR.message_types_by_name['VideoBumperInStreamAdInfo'] = _VIDEOBUMPERINSTREAMADINFO
DESCRIPTOR.message_types_by_name['VideoNonSkippableInStreamAdInfo'] = _VIDEONONSKIPPABLEINSTREAMADINFO
DESCRIPTOR.message_types_by_name['VideoTrueViewInStreamAdInfo'] = _VIDEOTRUEVIEWINSTREAMADINFO
DESCRIPTOR.message_types_by_name['VideoOutstreamAdInfo'] = _VIDEOOUTSTREAMADINFO
DESCRIPTOR.message_types_by_name['VideoAdInfo'] = _VIDEOADINFO
DESCRIPTOR.message_types_by_name['ResponsiveSearchAdInfo'] = _RESPONSIVESEARCHADINFO
DESCRIPTOR.message_types_by_name['LegacyResponsiveDisplayAdInfo'] = _LEGACYRESPONSIVEDISPLAYADINFO
DESCRIPTOR.message_types_by_name['AppAdInfo'] = _APPADINFO
DESCRIPTOR.message_types_by_name['AppEngagementAdInfo'] = _APPENGAGEMENTADINFO
DESCRIPTOR.message_types_by_name['LegacyAppInstallAdInfo'] = _LEGACYAPPINSTALLADINFO
DESCRIPTOR.message_types_by_name['ResponsiveDisplayAdInfo'] = _RESPONSIVEDISPLAYADINFO
DESCRIPTOR.message_types_by_name['DisplayUploadAdInfo'] = _DISPLAYUPLOADADINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextAdInfo = _reflection.GeneratedProtocolMessageType('TextAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _TEXTADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A text ad.
  
  
  Attributes:
      headline:
          The headline of the ad.
      description1:
          The first line of the ad's description.
      description2:
          The second line of the ad's description.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.TextAdInfo)
  ))
_sym_db.RegisterMessage(TextAdInfo)

ExpandedTextAdInfo = _reflection.GeneratedProtocolMessageType('ExpandedTextAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDTEXTADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An expanded text ad.
  
  
  Attributes:
      headline_part1:
          The first part of the ad's headline.
      headline_part2:
          The second part of the ad's headline.
      headline_part3:
          The third part of the ad's headline.
      description:
          The description of the ad.
      description2:
          The second description of the ad.
      path1:
          The text that can appear alongside the ad's displayed URL.
      path2:
          Additional text that can appear alongside the ad's displayed
          URL.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ExpandedTextAdInfo)
  ))
_sym_db.RegisterMessage(ExpandedTextAdInfo)

CallOnlyAdInfo = _reflection.GeneratedProtocolMessageType('CallOnlyAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _CALLONLYADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A call-only ad.
  
  
  Attributes:
      country_code:
          The country code in the ad.
      phone_number:
          The phone number in the ad.
      business_name:
          The business name in the ad.
      headline1:
          First headline in the ad.
      headline2:
          Second headline in the ad.
      description1:
          The first line of the ad's description.
      description2:
          The second line of the ad's description.
      call_tracked:
          Whether to enable call tracking for the creative. Enabling
          call tracking also enables call conversions.
      disable_call_conversion:
          Whether to disable call conversion for the creative. If set to
          ``true``, disables call conversions even when ``call_tracked``
          is ``true``. If ``call_tracked`` is ``false``, this field is
          ignored.
      phone_number_verification_url:
          The URL to be used for phone number verification.
      conversion_action:
          The conversion action to attribute a call conversion to. If
          not set a default conversion action is used. This field only
          has effect if call\_tracked is set to true. Otherwise this
          field is ignored.
      conversion_reporting_state:
          The call conversion behavior of this call only ad. It can use
          its own call conversion setting, inherit the account level
          setting, or be disabled.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CallOnlyAdInfo)
  ))
_sym_db.RegisterMessage(CallOnlyAdInfo)

ExpandedDynamicSearchAdInfo = _reflection.GeneratedProtocolMessageType('ExpandedDynamicSearchAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDDYNAMICSEARCHADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An expanded dynamic search ad.
  
  
  Attributes:
      description:
          The description of the ad.
      description2:
          The second description of the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ExpandedDynamicSearchAdInfo)
  ))
_sym_db.RegisterMessage(ExpandedDynamicSearchAdInfo)

HotelAdInfo = _reflection.GeneratedProtocolMessageType('HotelAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A hotel ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.HotelAdInfo)
  ))
_sym_db.RegisterMessage(HotelAdInfo)

ShoppingSmartAdInfo = _reflection.GeneratedProtocolMessageType('ShoppingSmartAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGSMARTADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A Smart Shopping ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ShoppingSmartAdInfo)
  ))
_sym_db.RegisterMessage(ShoppingSmartAdInfo)

ShoppingProductAdInfo = _reflection.GeneratedProtocolMessageType('ShoppingProductAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGPRODUCTADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A standard Shopping ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ShoppingProductAdInfo)
  ))
_sym_db.RegisterMessage(ShoppingProductAdInfo)

ShoppingComparisonListingAdInfo = _reflection.GeneratedProtocolMessageType('ShoppingComparisonListingAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGCOMPARISONLISTINGADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A Shopping Comparison Listing ad.
  
  
  Attributes:
      headline:
          Headline of the ad. This field is required. Allowed length is
          between 25 and 45 characters.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ShoppingComparisonListingAdInfo)
  ))
_sym_db.RegisterMessage(ShoppingComparisonListingAdInfo)

GmailAdInfo = _reflection.GeneratedProtocolMessageType('GmailAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _GMAILADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A Gmail ad.
  
  
  Attributes:
      teaser:
          The Gmail teaser.
      header_image:
          The MediaFile resource name of the header image. Valid image
          types are GIF, JPEG and PNG. The minimum size is 300x100
          pixels and the aspect ratio must be between 3:1 and 5:1
          (+-1%).
      marketing_image:
          The MediaFile resource name of the marketing image. Valid
          image types are GIF, JPEG and PNG. The image must either be
          landscape with a minimum size of 600x314 pixels and aspect
          ratio of 600:314 (+-1%) or square with a minimum size of
          300x300 pixels and aspect ratio of 1:1 (+-1%)
      marketing_image_headline:
          Headline of the marketing image.
      marketing_image_description:
          Description of the marketing image.
      marketing_image_display_call_to_action:
          Display-call-to-action of the marketing image.
      product_images:
          Product images. Up to 15 images are supported.
      product_videos:
          Product videos. Up to 7 videos are supported. At least one
          product video or a marketing image must be specified.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.GmailAdInfo)
  ))
_sym_db.RegisterMessage(GmailAdInfo)

GmailTeaser = _reflection.GeneratedProtocolMessageType('GmailTeaser', (_message.Message,), dict(
  DESCRIPTOR = _GMAILTEASER,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Gmail teaser data. The teaser is a small header that acts as an
  invitation to view the rest of the ad (the body).
  
  
  Attributes:
      headline:
          Headline of the teaser.
      description:
          Description of the teaser.
      business_name:
          Business name of the advertiser.
      logo_image:
          The MediaFile resource name of the logo image. Valid image
          types are GIF, JPEG and PNG. The minimum size is 144x144
          pixels and the aspect ratio must be 1:1 (+-1%).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.GmailTeaser)
  ))
_sym_db.RegisterMessage(GmailTeaser)

DisplayCallToAction = _reflection.GeneratedProtocolMessageType('DisplayCallToAction', (_message.Message,), dict(
  DESCRIPTOR = _DISPLAYCALLTOACTION,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Data for display call to action. The call to action is a piece of the ad
  that prompts the user to do something. Like clicking a link or making a
  phone call.
  
  
  Attributes:
      text:
          Text for the display-call-to-action.
      text_color:
          Text color for the display-call-to-action in hexadecimal, e.g.
          #ffffff for white.
      url_collection_id:
          Identifies the url collection in the ad.url\_collections
          field. If not set the url defaults to final\_url.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.DisplayCallToAction)
  ))
_sym_db.RegisterMessage(DisplayCallToAction)

ProductImage = _reflection.GeneratedProtocolMessageType('ProductImage', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTIMAGE,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Product image specific data.
  
  
  Attributes:
      product_image:
          The MediaFile resource name of the product image. Valid image
          types are GIF, JPEG and PNG. The minimum size is 300x300
          pixels and the aspect ratio must be 1:1 (+-1%).
      description:
          Description of the product.
      display_call_to_action:
          Display-call-to-action of the product image.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ProductImage)
  ))
_sym_db.RegisterMessage(ProductImage)

ProductVideo = _reflection.GeneratedProtocolMessageType('ProductVideo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTVIDEO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Product video specific data.
  
  
  Attributes:
      product_video:
          The MediaFile resource name of a video which must be hosted on
          YouTube.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ProductVideo)
  ))
_sym_db.RegisterMessage(ProductVideo)

ImageAdInfo = _reflection.GeneratedProtocolMessageType('ImageAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An image ad.
  
  
  Attributes:
      pixel_width:
          Width in pixels of the full size image.
      pixel_height:
          Height in pixels of the full size image.
      image_url:
          URL of the full size image.
      preview_pixel_width:
          Width in pixels of the preview size image.
      preview_pixel_height:
          Height in pixels of the preview size image.
      preview_image_url:
          URL of the preview size image.
      mime_type:
          The mime type of the image.
      name:
          The name of the image. If the image was created from a
          MediaFile, this is the MediaFile's name. If the image was
          created from bytes, this is empty.
      image:
          The image to create the ImageAd from. This can be specified in
          one of two ways. 1. An existing MediaFile resource. 2. The raw
          image data as bytes.
      media_file:
          The MediaFile resource to use for the image.
      data:
          Raw image data as bytes.
      ad_id_to_copy_image_from:
          An ad ID to copy the image from.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ImageAdInfo)
  ))
_sym_db.RegisterMessage(ImageAdInfo)

VideoBumperInStreamAdInfo = _reflection.GeneratedProtocolMessageType('VideoBumperInStreamAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _VIDEOBUMPERINSTREAMADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Representation of video bumper in-stream ad format (very short in-stream
  non-skippable video ad).
  
  
  Attributes:
      companion_banner:
          The MediaFile resource name of the companion banner used with
          the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.VideoBumperInStreamAdInfo)
  ))
_sym_db.RegisterMessage(VideoBumperInStreamAdInfo)

VideoNonSkippableInStreamAdInfo = _reflection.GeneratedProtocolMessageType('VideoNonSkippableInStreamAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _VIDEONONSKIPPABLEINSTREAMADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Representation of video non-skippable in-stream ad format (15 second
  in-stream non-skippable video ad).
  
  
  Attributes:
      companion_banner:
          The MediaFile resource name of the companion banner used with
          the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.VideoNonSkippableInStreamAdInfo)
  ))
_sym_db.RegisterMessage(VideoNonSkippableInStreamAdInfo)

VideoTrueViewInStreamAdInfo = _reflection.GeneratedProtocolMessageType('VideoTrueViewInStreamAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _VIDEOTRUEVIEWINSTREAMADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Representation of video TrueView in-stream ad format (ad shown during
  video playback, often at beginning, which displays a skip button a few
  seconds into the video).
  
  
  Attributes:
      action_button_label:
          Label on the CTA (call-to-action) button taking the user to
          the video ad's final URL. Required for TrueView for action
          campaigns, optional otherwise.
      action_headline:
          Additional text displayed with the CTA (call-to-action) button
          to give context and encourage clicking on the button.
      companion_banner:
          The MediaFile resource name of the companion banner used with
          the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.VideoTrueViewInStreamAdInfo)
  ))
_sym_db.RegisterMessage(VideoTrueViewInStreamAdInfo)

VideoOutstreamAdInfo = _reflection.GeneratedProtocolMessageType('VideoOutstreamAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _VIDEOOUTSTREAMADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Representation of video out-stream ad format (ad shown alongside a feed
  with automatic playback, without sound).
  
  
  Attributes:
      headline:
          The headline of the ad.
      description:
          The description line.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.VideoOutstreamAdInfo)
  ))
_sym_db.RegisterMessage(VideoOutstreamAdInfo)

VideoAdInfo = _reflection.GeneratedProtocolMessageType('VideoAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _VIDEOADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A video ad.
  
  
  Attributes:
      media_file:
          The MediaFile resource to use for the video.
      format:
          Format-specific schema for the different video formats.
      in_stream:
          Video TrueView in-stream ad format.
      bumper:
          Video bumper in-stream ad format.
      out_stream:
          Video out-stream ad format.
      non_skippable:
          Video non-skippable in-stream ad format.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.VideoAdInfo)
  ))
_sym_db.RegisterMessage(VideoAdInfo)

ResponsiveSearchAdInfo = _reflection.GeneratedProtocolMessageType('ResponsiveSearchAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSIVESEARCHADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A responsive search ad.
  
  Responsive search ads let you create an ad that adapts to show more
  text, and more relevant messages, to your customers. Enter multiple
  headlines and descriptions when creating a responsive search ad, and
  over time, Google Ads will automatically test different combinations and
  learn which combinations perform best. By adapting your ad's content to
  more closely match potential customers' search terms, responsive search
  ads may improve your campaign's performance.
  
  More information at https://support.google.com/google-ads/answer/7684791
  
  
  Attributes:
      headlines:
          List of text assets for headlines. When the ad serves the
          headlines will be selected from this list.
      descriptions:
          List of text assets for descriptions. When the ad serves the
          descriptions will be selected from this list.
      path1:
          First part of text that may appear appended to the url
          displayed in the ad.
      path2:
          Second part of text that may appear appended to the url
          displayed in the ad. This field can only be set when path1 is
          also set.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ResponsiveSearchAdInfo)
  ))
_sym_db.RegisterMessage(ResponsiveSearchAdInfo)

LegacyResponsiveDisplayAdInfo = _reflection.GeneratedProtocolMessageType('LegacyResponsiveDisplayAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _LEGACYRESPONSIVEDISPLAYADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A legacy responsive display ad. Ads of this type are labeled 'Responsive
  ads' in the Google Ads UI.
  
  
  Attributes:
      short_headline:
          The short version of the ad's headline.
      long_headline:
          The long version of the ad's headline.
      description:
          The description of the ad.
      business_name:
          The business name in the ad.
      allow_flexible_color:
          Advertiser's consent to allow flexible color. When true, the
          ad may be served with different color if necessary. When
          false, the ad will be served with the specified colors or a
          neutral color. The default value is true. Must be true if
          main\_color and accent\_color are not set.
      accent_color:
          The accent color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      main_color:
          The main color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      call_to_action_text:
          The call-to-action text for the ad.
      logo_image:
          The MediaFile resource name of the logo image used in the ad.
      square_logo_image:
          The MediaFile resource name of the square logo image used in
          the ad.
      marketing_image:
          The MediaFile resource name of the marketing image used in the
          ad.
      square_marketing_image:
          The MediaFile resource name of the square marketing image used
          in the ad.
      format_setting:
          Specifies which format the ad will be served in. Default is
          ALL\_FORMATS.
      price_prefix:
          Prefix before price. E.g. 'as low as'.
      promo_text:
          Promotion text used for dyanmic formats of responsive ads. For
          example 'Free two-day shipping'.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LegacyResponsiveDisplayAdInfo)
  ))
_sym_db.RegisterMessage(LegacyResponsiveDisplayAdInfo)

AppAdInfo = _reflection.GeneratedProtocolMessageType('AppAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _APPADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An app ad.
  
  
  Attributes:
      mandatory_ad_text:
          An optional text asset that, if specified, must always be
          displayed when the ad is served.
      headlines:
          List of text assets for headlines. When the ad serves the
          headlines will be selected from this list.
      descriptions:
          List of text assets for descriptions. When the ad serves the
          descriptions will be selected from this list.
      images:
          List of image assets that may be displayed with the ad.
      youtube_videos:
          List of YouTube video assets that may be displayed with the
          ad.
      html5_media_bundles:
          List of media bundle assets that may be used with the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.AppAdInfo)
  ))
_sym_db.RegisterMessage(AppAdInfo)

AppEngagementAdInfo = _reflection.GeneratedProtocolMessageType('AppEngagementAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _APPENGAGEMENTADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """App engagement ads allow you to write text encouraging a specific action
  in the app, like checking in, making a purchase, or booking a flight.
  They allow you to send users to a specific part of your app where they
  can find what they're looking for easier and faster.
  
  
  Attributes:
      headlines:
          List of text assets for headlines. When the ad serves the
          headlines will be selected from this list.
      descriptions:
          List of text assets for descriptions. When the ad serves the
          descriptions will be selected from this list.
      images:
          List of image assets that may be displayed with the ad.
      videos:
          List of video assets that may be displayed with the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.AppEngagementAdInfo)
  ))
_sym_db.RegisterMessage(AppEngagementAdInfo)

LegacyAppInstallAdInfo = _reflection.GeneratedProtocolMessageType('LegacyAppInstallAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _LEGACYAPPINSTALLADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A legacy app install ad that only can be used by a few select customers.
  
  
  Attributes:
      app_id:
          The id of the mobile app.
      app_store:
          The app store the mobile app is available in.
      headline:
          The headline of the ad.
      description1:
          The first description line of the ad.
      description2:
          The second description line of the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LegacyAppInstallAdInfo)
  ))
_sym_db.RegisterMessage(LegacyAppInstallAdInfo)

ResponsiveDisplayAdInfo = _reflection.GeneratedProtocolMessageType('ResponsiveDisplayAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSIVEDISPLAYADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A responsive display ad.
  
  
  Attributes:
      marketing_images:
          Marketing images to be used in the ad. Valid image types are
          GIF, JPEG, and PNG. The minimum size is 600x314 and the aspect
          ratio must be 1.91:1 (+-1%). At least one marketing\_image is
          required. Combined with square\_marketing\_images the maximum
          is 15.
      square_marketing_images:
          Square marketing images to be used in the ad. Valid image
          types are GIF, JPEG, and PNG. The minimum size is 300x300 and
          the aspect ratio must be 1:1 (+-1%). At least one square
          marketing\_image is required. Combined with marketing\_images
          the maximum is 15.
      logo_images:
          Logo images to be used in the ad. Valid image types are GIF,
          JPEG, and PNG. The minimum size is 512x128 and the aspect
          ratio must be 4:1 (+-1%). Combined with square\_logo\_images
          the maximum is 5.
      square_logo_images:
          Square logo images to be used in the ad. Valid image types are
          GIF, JPEG, and PNG. The minimum size is 128x128 and the aspect
          ratio must be 1:1 (+-1%). Combined with square\_logo\_images
          the maximum is 5.
      headlines:
          Short format headlines for the ad. The maximum length is 30
          characters. At least 1 and max 5 headlines can be specified.
      long_headline:
          A required long format headline. The maximum length is 90
          characters.
      descriptions:
          Descriptive texts for the ad. The maximum length is 90
          characters. At least 1 and max 5 headlines can be specified.
      youtube_videos:
          Optional YouTube vidoes for the ad. A maximum of 5 videos can
          be specified.
      business_name:
          The advertiser/brand name. Maximum display width is 25.
      main_color:
          The main color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      accent_color:
          The accent color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      allow_flexible_color:
          Advertiser's consent to allow flexible color. When true, the
          ad may be served with different color if necessary. When
          false, the ad will be served with the specified colors or a
          neutral color. The default value is true. Must be true if
          main\_color and accent\_color are not set.
      call_to_action_text:
          The call-to-action text for the ad. Maximum display width is
          30.
      price_prefix:
          Prefix before price. E.g. 'as low as'.
      promo_text:
          Promotion text used for dyanmic formats of responsive ads. For
          example 'Free two-day shipping'.
      format_setting:
          Specifies which format the ad will be served in. Default is
          ALL\_FORMATS.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ResponsiveDisplayAdInfo)
  ))
_sym_db.RegisterMessage(ResponsiveDisplayAdInfo)

DisplayUploadAdInfo = _reflection.GeneratedProtocolMessageType('DisplayUploadAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _DISPLAYUPLOADADINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A generic type of display ad. The exact ad format is controlled by the
  display\_upload\_product\_type field, which determines what kinds of
  data need to be included with the ad.
  
  
  Attributes:
      display_upload_product_type:
          The product type of this ad. See comments on the enum for
          details.
      media_asset:
          The asset data that makes up the ad.
      media_bundle:
          A media bundle asset to be used in the ad. For information
          about the media bundle for HTML5\_UPLOAD\_AD see
          https://support.google.com/google-ads/answer/1722096 Media
          bundles that are part of dynamic product types use a special
          format that needs to be created through the Google Web
          Designer. See
          https://support.google.com/webdesigner/answer/7543898 for more
          information.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.DisplayUploadAdInfo)
  ))
_sym_db.RegisterMessage(DisplayUploadAdInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
